<?php
/**
 * This file belongs to the YIT Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

/**
 * Return an array with the options for Theme Options > Typography and Color > Buttons
 *
 * @package Yithemes
 * @author  Andrea Grillo <andrea.grillo@yithemes.com>
 * @author  Antonio La Rocca <antonio.larocca@yithemes.it>
 * @since   2.0.0
 * @return mixed array
 *
 */
return array(

    /* Typography and Color > Buttons */

    array(
        'type' => 'title',
        'name' => __( 'Buttons Flat', 'yit' ),
        'desc' => ''
    ),

    array(
        'id'              => 'button-font',
        'type'            => 'typography',
        'name'            => __( 'Buttons Typography', 'yit' ),
        'desc'            => __( 'Select the typography for buttons text.', 'yit' ),
        'min'             => 1,
        'max'             => 80,
        'default_font_id' => 'typography-website-title',
        'std'             => array(
            'size'      => 11,
            'unit'      => 'px',
            'family'    => 'default',
            'style'     => '400',
            'transform' => 'uppercase',
        ),
        'style'             => array(
        'selectors'         =>  '.btn-flat, a.btn-flat,
                                .modal-shortcode .modal-opener a.btn-flat,
                                .parallaxeos_animate a.btn-flat span,
                                #header-row .yit-custom-megamenu > div > ul > li > a,
                                input.button,
                                a.btn.btn-flat.animated span,
                                .recent-post .hentry-post p.post-date .day,
                                .recent-post .hentry-post p.post-date .month,
                                .yith-wcwl-wishlistaddedbrowse span.feedback,
                                #yith-wcwl-form a.button,
                                table.my_account_orders a.button.view,
                                table.my_account_orders a.button.cancel,
                                table.my_account_orders a.button.pay,
                                .woocommerce-message .button.wc-forward,
                                .woocommerce-error .button.wc-forward,
                                button.single_add_to_cart_button.button,
                                .button.compare,
                                .blog input[type="submit"],
                                #my-account-content p.order-again a.button,
                                a.track-button,
                                .blog .more-link, .blog .read-more,
                                .woocommerce table.my_account_orders .order-actions a.track-button,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a,
                                a.button.add-request-quote-button,
                                .yith-wcwtl-msg + a.button.button-leave,
                                a.stop-reply.button,
                                a.yith-wcan-reset-navigation',

            'properties' => 'font-size,
                              font-family,
                              font-weight,
                              text-transform'
        )
    ),

    array(
        'id'         => 'button-text-color',
        'type'       => 'colorpicker',
        'name'       => __( 'Buttons Text color', 'yit' ),
        'desc'       => __( 'Select the color of the text for the buttons of every page', 'yit' ),
        'variations' => array(
            'normal' => __( 'Text color', 'yit' ),
            'hover'  => __( 'Text hover color', 'yit' )
        ),
        'std'        => array(
            'color' => array(
                'normal' => '#ffffff',
                'hover'  => '#ffffff'
            )
        ),
        'style'      => array(
            'normal' => array(
                'selectors'  => '.btn-flat, a.btn-flat, a.btn-flat.added,
                                .modal-shortcode .modal-opener a.btn-flat,
                                #header-row .yit-custom-megamenu > div > ul > li > a,
                                .nav  span.highlight-inverse,
                                input.button,
                                .btn.btn-flat i.fa,
                                .btn.btn-alternative i.fa,
                                a.btn.btn-flat.animated span,
                                .recent-post .hentry-post p.post-date .day,
                                .recent-post .hentry-post p.post-date .month,
                                .parallaxeos_animate a.btn-flat span,
                                .yith-wcwl-wishlistaddedbrowse span.feedback,
                                #yith-wcwl-form a.button,
                                table.my_account_orders a.button.view,
                                table.my_account_orders a.button.cancel,
                                table.my_account_orders a.button.pay,
                                .woocommerce-message .button.wc-forward,
                                a[class^=eg-portfolio-masonry],
                                .woocommerce-error .button.wc-forward,
                                button.single_add_to_cart_button.button,
                                .blog input[type="submit"],
                                .button.compare,
                                #my-account-content p.order-again a.button,
                                a.track-button,
                                .blog .more-link, .blog .read-more,
                                .woocommerce table.my_account_orders .order-actions a.track-button,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a,
                                a.button.add-request-quote-button,
                                .yith-wcwtl-msg + a.button.button-leave,
                                a.stop-reply.button,
                                a.yith-wcan-reset-navigation,
                                .tp-caption a',

                'properties' => 'color'
            ),
            'hover'  => array(
                'selectors'  => '.btn-flat:hover, a.btn-flat:hover,
                                #header-row .yit-custom-megamenu > div > ul > li > a:hover,
                                input.button:hover,
                                .parallaxeos_animate a.btn-flat:hover span,
                                #yith-wcwl-form a.button:hover,
                                .btn.btn-flat:hover i.fa,
                                a.btn.btn-flat.animated:hover span,
                                .btn.btn-alternative:hover i.fa,
                                table.my_account_orders a.button.view:hover,
                                table.my_account_orders a.button.cancel:hover,
                                table.my_account_orders a.button.pay:hover,
                                .woocommerce-message .button.wc-forward:hover,
                                .woocommerce-error .button.wc-forward:hover,
                                button.single_add_to_cart_button.button:hover,
                                .blog input[type="submit"]:hover,
                                .button.compare:hover,
                                #my-account-content p.order-again a.button:hover,
                                a.track-button:hover,
                                .blog .more-link:hover, .blog .read-more:hover,
                                .woocommerce table.my_account_orders .order-actions a.track-button:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a:hover,
                                a.button.add-request-quote-button:hover,
                                .yith-wcwtl-msg + a.button.button-leave:hover,
                                a.stop-reply.button:hover,
                                a.yith-wcan-reset-navigation:hover,
                                .tp-caption a:hover',

                'properties' => 'color'
            )
        )
    ),

    array(
        'id'         => 'button-border-color',
        'type'       => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Border color', 'yit' ),
            'hover'  => __( 'Border hover color', 'yit' )
        ),
        'name'       => __( 'Buttons border color', 'yit' ),
        'desc'       => __( 'Select a color for the buttons border of all pages.', 'yit' ),
        'std'        => array(
            'color' => array(
                'normal' => '#000000',
                'hover'  => '#434343'
            )
        ),
        'style'      => array(
            'normal' => array(
                'selectors'  => '.btn-flat, a.btn-flat,
                                #header-row .yit-custom-megamenu > div > ul > li > a,
                                .yith-wcwl-wishlistaddedbrowse span.feedback,
                                .parallaxeos_animate a.btn-flat span,
                                input.button,
                                #yith-wcwl-form a.button,
                                table.my_account_orders a.button.view,
                                table.my_account_orders a.button.cancel,
                                table.my_account_orders a.button.pay,
                                .woocommerce-message .button.wc-forward,
                                .woocommerce-error .button.wc-forward,
                                button.single_add_to_cart_button.button,
                                .blog input[type="submit"],
                                .button.compare,
                                #my-account-content p.order-again a.button,
                                a.track-button,
                                .blog .more-link, .blog .read-more,
                                .woocommerce table.my_account_orders .order-actions a.track-button,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a,
                                a.button.add-request-quote-button,
                                .yith-wcwtl-msg + a.button.button-leave,
                                a.stop-reply.button,
                                a.yith-wcan-reset-navigation',

                'properties' => 'border-color'
            ),
            'hover'  => array(
                'selectors'  => '.btn-flat:hover, a.btn-flat:hover,
                                #header-row .yit-custom-megamenu > div > ul > li > a:hover,
                                .parallaxeos_animate a.btn-flat:hover span,
                                input.button:hover,
                                #yith-wcwl-form a.button:hover,
                                table.my_account_orders a.button.view:hover,
                                table.my_account_orders a.button.cancel:hover,
                                table.my_account_orders a.button.pay:hover,
                                .woocommerce-message .button.wc-forward:hover,
                                .woocommerce-error .button.wc-forward:hover,
                                button.single_add_to_cart_button.button:hover,
                                .blog input[type="submit"]:hover,
                                .button.compare:hover,
                                #my-account-content p.order-again a.button:hover,
                                a.track-button:hover,
                                .blog .more-link:hover, .blog .read-more:hover,
                                .woocommerce table.my_account_orders .order-actions a.track-button:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a:hover,
                                a.button.add-request-quote-button:hover,
                                .yith-wcwtl-msg + a.button.button-leave:hover,
                                a.stop-reply.button:hover,
                                a.yith-wcan-reset-navigation:hover',

                'properties' => 'border-color'
            )
        )
    ),

    array(
        'id'         => 'button-background-color',
        'type'       => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Background color', 'yit' ),
            'hover'  => __( 'Background hover color', 'yit ' )
        ),
        'name'       => __( 'Buttons background color', 'yit' ),
        'desc'       => __( 'Select a color for the buttons background of all pages.', 'yit' ),
        'std'        => array(
            'color' => array(
                'normal' => '#000000',
                'hover'  => '#434343'
            )
        ),
        'style'      => array(
            'normal' => array(
                'selectors'  => '.btn-flat, a.btn-flat,
                                #header-row .yit-custom-megamenu > div > ul > li > a,
                                .nav  span.highlight-inverse,
                                .parallaxeos_animate a.btn-flat span,
                                input.button,
                                #yith-wcwl-form a.button,
                                table.my_account_orders a.button.view,
                                table.my_account_orders a.button.cancel,
                                table.my_account_orders a.button.pay,
                                .woocommerce-message .button.wc-forward,
                                .woocommerce-error .button.wc-forward,
                                button.single_add_to_cart_button.button,
                                .blog input[type="submit"],
                                .button.compare,
                                #my-account-content p.order-again a.button,
                                a.track-button,
                                .blog .more-link, .blog .read-more,
                                .woocommerce table.my_account_orders .order-actions a.track-button,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a,
                                a.button.add-request-quote-button,
                                .yith-wcwtl-msg + a.button.button-leave,
                                a.stop-reply.button,
                                a.yith-wcan-reset-navigation',

                'properties' => 'background-color, background'
            ),
            'hover'  => array(
                'selectors'  => '.btn-flat:hover, a.btn-flat:hover,
                                #header-row .yit-custom-megamenu > div > ul > li > a:hover,
                                input.button:hover,
                                .parallaxeos_animate a.btn-flat:hover span,
                                #yith-wcwl-form a.button:hover,
                                table.my_account_orders a.button.view:hover,
                                table.my_account_orders a.button.cancel:hover,
                                table.my_account_orders a.button.pay:hover,
                                .woocommerce-message .button.wc-forward:hover,
                                .woocommerce-error .button.wc-forward:hover,
                                button.single_add_to_cart_button.button:hover,
                                .blog input[type="submit"]:hover,
                                .button.compare:hover,
                                #my-account-content p.order-again a.button:hover,
                                a.track-button:hover,
                                .blog .more-link:hover, .blog .read-more:hover,
                                .woocommerce table.my_account_orders .order-actions a.track-button:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary a.yith-wcqv-view-details:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary a.compare:hover,
                                .yith-quick-view-content.woocommerce div.entry-summary .yith-wcwl-add-to-wishlist a:hover,
                                a.button.add-request-quote-button:hover,
                                .yith-wcwtl-msg + a.button.button-leave:hover,
                                a.stop-reply.button:hover,
                                a.yith-wcan-reset-navigation:hover',

                'properties' => 'background-color, background'
            )
        )
    ),

    /* ========= Button Alternative =========== */

    array(
        'type' => 'title',
        'name' => __( 'Buttons Alternative', 'yit' ),
        'desc' => ''
    ),

    array(
        'id'              => 'button-font-alternative',
        'type'            => 'typography',
        'name'            => __( 'Buttons Alternative Typography', 'yit' ),
        'desc'            => __( 'Select the typography for alternative buttons text.', 'yit' ),
        'min'             => 1,
        'max'             => 80,
        'default_font_id' => 'typography-website-title',
        'std'             => array(
            'size'      => 11,
            'unit'      => 'px',
            'family'    => 'default',
            'style'     => '400',
            'transform' => 'uppercase',
        ),
        'style'           => array(
            'selectors'  => '.btn-alternative, a.btn-alternative, #submit,
                            .modal-shortcode .modal-opener a.btn-alternative,
                             input.button.button-register.btn-alternative,
                             .register input.button.btn-alternative,
                             a.btn.btn-alternative.animated span,
                             .widget.widget_search #searchform #searchsubmit,.woocommerce-product-search input[type="submit"],
                             .error-404-container .error-404-search #searchsubmit,
                             .widget.widget_price_filter button[type="submit"],
                             .widget_product_search #searchform #searchsubmit,
                              .call-three .newsletter-cta-form-container input[type="submit"],
                              input#place_order,
                              .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist,
                              .submit-wishlist-changes,
                              .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button,
                              .woocommerce .yith-wcwl-wishlist-new button,
                              a.yith-wcqv-button,
                              .yith-wcwtl-msg + a.button:not(.button-leave),
                              .ask-an-estimate-button.ask-an-estimate-button-popup,
                              a.wishlist-submit.add_to_wishlist.popup_button,
                              a.comment-reply-link.button,
                              .variations_button .single_add_to_cart_button.button.alt',
            'properties' => 'font-size,
                              font-family,
                              font-weight,
                              text-transform'
        )
    ),

    array(
        'id'         => 'button-hover-color-alternative',
        'type'       => 'colorpicker',
        'name'       => __( 'Buttons Alternative Text Color', 'yit' ),
        'desc'       => __( 'Select the color of the text for the alternative buttons of every page', 'yit' ),
        'variations' => array(
            'normal' => __( 'Text color', 'yit' ),
            'hover'  => __( 'Text hover color', 'yit ' )
        ),
        'std'        => array(
            'color' => array(
                'normal' => '#ffffff',
                'hover'  => '#ffffff'
            )
        ),
        'style'      => array(
            'normal' => array(
                'selectors'  => '.btn-alternative, a.btn-alternative, a.btn-alternative:active, #submit,
                                #my-account-sidebar .user-profile span.logout a,
                                .modal-shortcode .modal-opener a.btn-alternative,
                                input.button.button-register.btn-alternative,
                                .widget.widget_search #searchform #searchsubmit, .woocommerce-product-search input[type="submit"],
                                .parallaxeos_animate a.btn-alternative span,
                                #my-account-content .addresses .title a.edit,
                                .register input.button.btn-alternative,
                                a.btn.btn-alternative.animated span,
                                .error-404-container .error-404-search #searchsubmit,
                                .widget.widget_price_filter button[type="submit"],
                                .widget_product_search #searchform #searchsubmit,
                                #subscription-toggle span a,
                                #favorite-toggle span a,
                                .call-three .newsletter-cta-form-container input[type="submit"],
                                input#place_order,
                                .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist,
                                .submit-wishlist-changes,
                                .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button,
                                .woocommerce .yith-wcwl-wishlist-new button,
                                a.yith-wcqv-button,
                                .yith-wcwtl-msg + a.button:not(.button-leave),
                                .ask-an-estimate-button.ask-an-estimate-button-popup,
                                a.wishlist-submit.add_to_wishlist.popup_button,
                                a.comment-reply-link.button,
                                .variations_button .single_add_to_cart_button.button.alt',

                'properties' => 'color'
            ),
            'hover'  => array(
                'selectors'  => '.btn-alternative:hover, a.btn-alternative:hover, #submit:hover,
                                #my-account-sidebar .user-profile span.logout:hover a,
                                input.button.button-register.btn-alternative:hover,
                                .widget.widget_search #searchform #searchsubmit:hover, .woocommerce-product-search input[type="submit"]:hover,
                                #my-account-content .addresses .title a.edit:hover,
                                a.btn.btn-alternative.animated:hover span,
                                .register input.button.btn-alternative:hover,
                                .error-404-container .error-404-search #searchsubmit:hover,
                                .widget.widget_price_filter button[type="submit"]:hover,
                                .widget_product_search #searchform #searchsubmit:hover,
                                .call-three .newsletter-cta-form-container input[type="submit"]:hover,
                                input#place_order:hover,
                                .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist:hover,
                                .submit-wishlist-changes:hover,
                                .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button:hover,
                                .woocommerce .yith-wcwl-wishlist-new button:hover,
                                a.yith-wcqv-button:hover,
                                .yith-wcwtl-msg + a.button:not(.button-leave):hover,
                                .ask-an-estimate-button.ask-an-estimate-button-popup:hover,
                                a.wishlist-submit.add_to_wishlist.popup_button:hover,
                                a.comment-reply-link.button:hover,
                                .variations_button .single_add_to_cart_button.button.alt:hover',

                'properties' => 'color'
            )
        )
    ),

    array(
        'id'         => 'button-border-color-alternative',
        'type'       => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Border color', 'yit' ),
            'hover'  => __( 'Border hover color', 'yit' )
        ),
        'linked_to'  => array(
            'normal' => 'theme-color-2'
        ),
        'name'       => __( 'Buttons Alternative border color', 'yit' ),
        'desc'       => __( 'Select a color for the alternative buttons border of all pages.', 'yit' ),
        'std'        => array(
            'color' => array(
                'normal' => '#c8146e',
                'hover'  => '#8a0045'
            )
        ),
        'style'      => array(
            'normal' => array(
                'selectors'  => '.btn-alternative, a.btn-alternative, #submit,
                                 input.button.button-register.btn-alternative,
                                 .widget.widget_search #searchform #searchsubmit, .woocommerce-product-search input[type="submit"],
                                 .error-404-container .error-404-search #searchsubmit,
                                 .register input.button.btn-alternative,
                                 .widget.widget_price_filter button[type="submit"],
                                 .call-three .newsletter-cta-form-container input[type="submit"],
                                 input#place_order,
                                 .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist,
                                 .submit-wishlist-changes,
                                 .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button,
                                 .woocommerce .yith-wcwl-wishlist-new button,
                                 .woocommerce-tabs ul.tabs li.active a, .woocommerce-tabs ul.tabs li a:hover,
                                 .tabs-container ul.tabs li.current h4, .tabs-container ul.tabs li:hover h4,
                                 a.yith-wcqv-button,
                                 .yith-wcwtl-msg + a.button:not(.button-leave),
                                 .ask-an-estimate-button.ask-an-estimate-button-popup,
                                 a.wishlist-submit.add_to_wishlist.popup_button,
                                 a.comment-reply-link.button,
                                 #tab-reviews a.ywar_filter_order.active,
                                 #tab-reviews a.ywar_filter_order:hover,
                                 .wpb_content_element .wpb_tabs_nav li.ui-tabs-active,
                                 .wpb_content_element .wpb_tabs_nav li:hover,
                                 .wpb-js-composer .vc_tta.vc_tta-style-classic .vc_tta-tab.vc_active,
                                 .variations_button .single_add_to_cart_button.button.alt,
                                 body.wpb-js-composer .vc_tta.vc_tta-spacing-1 .vc_tta-tab:hover',

                'properties' => 'border-color'
            ),
            'hover'  => array(
                'selectors'  => '.btn-alternative:hover, a.btn-alternative:hover, #submit:hover,
                                 .widget.widget_search #searchform #searchsubmit:hover, .woocommerce-product-search input[type="submit"]:hover,
                                 input.button.button-register.btn-alternative:hover,
                                 .register input.button.btn-alternative:hover,
                                 .error-404-container .error-404-search #searchsubmit:hover,
                                 .widget.widget_price_filter button[type="submit"]:hover,
                                 .call-three .newsletter-cta-form-container input[type="submit"]:hover,
                                 input#place_order:hover,
                                 .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist:hover,
                                 .submit-wishlist-changes:hover,
                                 .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button:hover,
                                 .woocommerce .yith-wcwl-wishlist-new button:hover,
                                 a.yith-wcqv-button:hover,
                                 .yith-wcwtl-msg + a.button:not(.button-leave),
                                 .ask-an-estimate-button.ask-an-estimate-button-popup:hover,
                                 a.wishlist-submit.add_to_wishlist.popup_button:hover,
                                 a.comment-reply-link.button:hover,
                                 .variations_button .single_add_to_cart_button.button.alt:hover',

                'properties' => 'border-color'
            )
        )
    ),

    array(
        'id'         => 'button-background-color-alternative',
        'type'       => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Background color', 'yit' ),
            'hover'  => __( 'Background hover color', 'yit ' )
        ),
        'linked_to'  => array(
            'normal' => 'theme-color-1'
        ),
        'name'       => __( 'Buttons Alternative background color', 'yit' ),
        'desc'       => __( 'Select a color for the alternative buttons background of all pages.', 'yit' ),
        'std'        => array(
            'color' => array(
                'normal' => '#c8146e',
                'hover'  => '#8a0045'
            )
        ),
        'style'      => array(
            'normal' => array(
                'selectors'  => '.btn-alternative, a.btn-alternative, #submit,
                                #my-account-sidebar .user-profile span.logout,
                                input.button.button-register.btn-alternative,
                                .widget.widget_search #searchform #searchsubmit, .woocommerce-product-search input[type="submit"],
                                .nav  span.highlight,
                                .register input.button.btn-alternative,
                                #my-account-content .addresses .title a.edit,
                                .error-404-container .error-404-search #searchsubmit,
                                .widget.widget_price_filter button[type="submit"],
                                .widget_product_search #searchform #searchsubmit,
                                .call-three .newsletter-cta-form-container input[type="submit"],
                                input#place_order,
                                .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist,
                                .submit-wishlist-changes,
                                .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button,
                                .woocommerce .yith-wcwl-wishlist-new button,
                                a.yith-wcqv-button,
                                .yith-wcwtl-msg + a.button:not(.button-leave),
                                .ask-an-estimate-button.ask-an-estimate-button-popup,
                                a.wishlist-submit.add_to_wishlist.popup_button,
                                a.comment-reply-link.button,
                                .variations_button .single_add_to_cart_button.button.alt',

                'properties' => 'background-color, background'
            ),
            'hover'  => array(
                'selectors'  => '.btn-alternative:hover, a.btn-alternative:hover, #submit:hover,
                                #my-account-sidebar .user-profile span.logout:hover,
                                #my-account-content .addresses .title a.edit:hover,
                                .widget.widget_search #searchform #searchsubmit:hover, .woocommerce-product-search input[type="submit"]:hover,
                                input.button.button-register.btn-alternative:hover,
                                .register input.button.btn-alternative:hover,
                                .error-404-container .error-404-search #searchsubmit:hover,
                                .widget.widget_price_filter button[type="submit"]:hover,
                                .widget_product_search #searchform #searchsubmit:hover,
                                .call-three .newsletter-cta-form-container input[type="submit"]:hover,
                                input#place_order:hover,
                                .yith-wcwl-popup-button .add_to_wishlist.single_add_to_wishlist:hover,
                                .submit-wishlist-changes:hover,
                                .woocommerce .yith-wcwl-wishlist-search-form button.wishlist-search-button:hover,
                                .woocommerce .yith-wcwl-wishlist-new button:hover,
                                a.yith-wcqv-button:hover,
                                .yith-wcwtl-msg + a.button:not(.button-leave):hover,
                                .ask-an-estimate-button.ask-an-estimate-button-popup:hover,
                                a.wishlist-submit.add_to_wishlist.popup_button:hover,
                                a.comment-reply-link.button:hover,
                                .variations_button .single_add_to_cart_button.button.alt:hover',

                'properties' => 'background-color, background'
            )
        )
    ),

);

